<?php
/* ========================================================================
 - [webapp/libs/wap_private.php]
 -      private用WebApplicationクラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/07/05] 絵文字コンバートで文字コードの変更はなし
 -      [2006/09/20] $this->base['uri_separator']を追加
 -      [2006/07/10] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_validate.php';
require_once LIB_DIR.'rkt_auth.php';
require_once LIB_DIR.'rkt_emoji.php';
require_once LIB_DIR.'rkt_webapp.php';

/**
 * private用WebApplicationクラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package WAP_private
 * @access public
 * @version 1.0
 */
class WAP_private extends RKT_webapp
{
    /**
     * PHPSESSID
     * @var string
     */
    var $sid = '';

    /**
     * アカウント情報
     * @var object
     */
    var $account = array();

    /**
     * error情報
     * @var boolean
     */
    var $error = false;

    /**
     * コンストラクタ
     *
     * @access public
     */
    function WAP_private()
    {
        $this->RKT_webapp();

        $objact = account::getInstance();
        $this->sid = $objact->getSessionID();
        $this->account = $objact->getInfo();

        $this->set_account_info();
        $this->base['account'] = $this->account;

        $this->__initialize();
    }

    /**
     * MobileAppの初期化
     *
     * @access private
     * @return void
     */
    function __initialize()
    {
        $this->smarty->register_outputfilter('tpl_utf2sjis');

        foreach ($_POST as $key=> $value){
            if (is_string($value)){
                $_POST[$key] = mb_convert_encoding($value, ENCODE_TYPE, 'SJIS');
                $_REQUEST[$key] = $_POST[$key];
            }
        } // foreach ($_POST as $key=> $value)

        foreach ($_GET as $key=> $value){
            if (is_string($value)){
                $_GET[$key] = mb_convert_encoding($value, ENCODE_TYPE, 'SJIS');
                $_REQUEST[$key] = $_GET[$key];
            }
        } // foreach ($_GET as $key=> $value)
        
        $this->base['sid']    = session_id();
        $this->base['url']    = BASE_URL;
        $this->base['http']   = HTTP_ACTION;
        $this->base['ssl']    = SSL_ACTION;
        $this->base['config'] = 'private.conf';

        $this->base['uri_separator']  = htmlspecialchars(WAP_URI_SEPARATOR);
    }

    /**
     * 実行処理
     *
     * @access public
     **/
    function execute()
    {
    }

    /**
     * 表示処理
     *
     * @access public
     * @return void
     **/
    function display()
    {
        if ($this->error){
            $this->template_file = 'error.tpl';
            error_log('WAP_private::error'."\r\n", 3, ERROR_LOG_FILE);
        }
        $this->mixOutput();
    }

    /**
     * アカウント情報の設定
     *
     * @access private
     * @return void
     **/
    function set_account_info()
    {
        $sql=
            'SELECT '.
                'act.id as id,'.
                'act.friend_number as friend_number,'.
                'pro.nickname as nickname,'.
                'pro.publicity as publicity,'.
                'pht.filename as href,'.
                'pht.thumbnail as src,'.
                'pht.t_width as width,'.
                'pht.t_height as height '.
            'FROM '.
                DB_PREFIX.'act_account act '.
                    'LEFT JOIN '.DB_PREFIX.'act_photo pht '.
                    'ON act.id = pht.ref_account AND '.
                        'pht.status = '.STATUS_PHOTO_MAIN.','.
                DB_PREFIX.'act_profile pro '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                'act.id = '.$this->account['id'];
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $this->account = $stmt->fetch(PDO_FETCH_ASSOC);

        if (empty($this->account['src'])){
            $this->account['href']   = NOPHOTO_LARGE;
            $this->account['src']    = NOPHOTO_SMALL;
            $this->account['width']  = PHOTO_SMALL_SIZE;
            $this->account['height'] = PHOTO_SMALL_SIZE;
        }
    }

    /**
     * 絵文字コンバート
     *
     * @access public
     * @return void
     **/
    function emojiConvert($string)
    {
        static $objemoji;
        
        if (empty($objemoji)) {        
            $objemoji = new RKT_emoji();
        }
        $string = $objemoji->convert($string, 'Tag');

        return $string;
    }
}
// WAP_privateの終了
?>
